start

poglossary has been superseded by poterminology

# poglossary

This tool takes a directory of translated PO files and creates a single PO file containing terms and / or phrases that can be used as a glossary. This compendium can be used to review word choice of a subset of words, and can be a useful start for a your terminology in Pootle or many other offline editors.

## Prerequisites

The Translate Toolkit

GNU Gettext:

- msgattrib
- msgcat
- msgfilter

## Latest version

poglossary is not distributed with all versions of the toolkit. You can get the latest version from Subversion

## Usage

    poglossary <language-iso-code> <input-dir> <project-name>

Where:

language-iso-code | the ISO 639 code for your language (eg AF for Afrikaans, EN for English, etc)
input-dir | the directory with PO files from which you want to extract terms
project-name | the name of the project or domain from which you are extract terms

## Operation

poglossary makes use of pocompendium and some tools of the translate toolkit. It searches for all short terms and phrases in the PO files from the input directory and combines it into one file. Output is given in PO, CSV and TBX formats.